@@ -68,9 +68,16 @@ testConstraints <- function(model, qhat, uhat, constraints, method=c("D1","D2"),
       coef.method <- "nlme"
     }
 
+    # geeglm (geepack)
+    if(any(grepl("geeglm",cls)) & coef.method=="default"){
+      if(!requireNamespace("geepack", quietly=TRUE)) stop("The 'geepack' package must be installed in order to handle 'geeglm' class objects.")
+      coef.method <- "geeglm"
+    }
+
     fe <- switch(coef.method,
       lmer=.getCOEF.lmer(model),
       nlme=.getCOEF.nlme(model),
+      geeglm=.getCOEF.geeglm(model),
       default=.getCOEF.default(model)
     )
 
@@ -161,7 +168,7 @@ testConstraints <- function(model, qhat, uhat, constraints, method=c("D1","D2"),
   }
 
   out <- matrix(c(val,k,v,p,r),ncol=5)
-  colnames(out) <- c("F.value","df1","df2","p.value","RIV")
+  colnames(out) <- c("F.value","df1","df2","P(>F)","RIV")   # new label for p-value, SiG 2017-02-09
 
   out <- list(
     call=match.call(),
